@@ -26,9 +26,10 @@
 #include <QStringList>
 #include <QVariant>
 #include <QWeakPointer>
-
 #include <QDebug>
 
+#include "krunner_debug.h"
+
 #include "abstractrunner.h"
 
 namespace Plasma
@@ -53,17 +54,19 @@ class QueryMatchPrivate : public QSharedData
             : QSharedData(other),
               lock(new QReadWriteLock(QReadWriteLock::Recursive))
         {
-            QReadLocker lock(other.lock);
+            QReadLocker l(other.lock);
             runner = other.runner;
             type = other.type;
             relevance = other.relevance;
             selAction = other.selAction;
             enabled = other.enabled;
             idSetByData = other.idSetByData;
+            matchCategory = other.matchCategory;
             id = other.id;
             text = other.text;
             subtext = other.subtext;
             icon = other.icon;
+            iconName = other.iconName;
             data = other.data;
             mimeType = other.mimeType;
             urls = other.urls;
@@ -84,6 +87,7 @@ class QueryMatchPrivate : public QSharedData
         QString mimeType;
         QList<QUrl> urls;
         QIcon icon;
+        QString iconName;
         QVariant data;
         qreal relevance;
         QAction *selAction;
@@ -94,7 +98,7 @@ class QueryMatchPrivate : public QSharedData
 QueryMatch::QueryMatch(AbstractRunner *runner)
     : d(new QueryMatchPrivate(runner))
 {
-//    qDebug() << "new match created";
+//    qCDebug(KRUNNER) << "new match created";
 }
 
 QueryMatch::QueryMatch(const QueryMatch &other)
@@ -137,7 +141,7 @@ void QueryMatch::setMatchCategory(const QString &category)
 
 QString QueryMatch::matchCategory() const
 {
-    if (d->matchCategory.isEmpty()) {
+    if (d->matchCategory.isEmpty() && d->runner) {
         return d->runner->name();
     }
     return d->matchCategory;
@@ -204,6 +208,12 @@ void QueryMatch::setIcon(const QIcon &icon)
     d->icon = icon;
 }
 
+void QueryMatch::setIconName(const QString &iconName)
+{
+    QWriteLocker locker(d->lock);
+    d->iconName = iconName;
+}
+
 QVariant QueryMatch::data() const
 {
     QReadLocker locker(d->lock);
@@ -228,6 +238,12 @@ QIcon QueryMatch::icon() const
     return d->icon;
 }
 
+QString QueryMatch::iconName() const
+{
+    QReadLocker locker(d->lock);
+    return d->iconName;
+}
+
 void QueryMatch::setMimeType(const QString &mimeType)
 {
     QWriteLocker locker(d->lock);
@@ -314,7 +330,7 @@ bool QueryMatch::operator!=(const QueryMatch &other) const
 
 void QueryMatch::run(const RunnerContext &context) const
 {
-    //qDebug() << "we run the term" << context->query() << "whose type is" << context->mimetype();
+    //qCDebug(KRUNNER) << "we run the term" << context->query() << "whose type is" << context->mimetype();
     if (d->runner) {
         d->runner.data()->run(context, *this);
     }
